
Neural models
-------------


Sparse models
=============

.. autoxpmconfig:: xpmir.neural.splade.Splade


Dense models
============

:: autoxpmconfig::

Interaction models
==================

.. autoxpmconfig:: xpmir.neural.InteractionScorer
.. autoxpmconfig:: xpmir.neural.drmm.Drmm

.. autoxpmconfig:: xpmir.neural.colbert.Colbert
